TGLogLevel enum

Inheritance
Available extensions

Values

ALL → const TGLogLevel
TAG → const TGLogLevel
DEBUG → const TGLogLevel
INFO → const TGLogLevel
WARN → const TGLogLevel
ERROR → const TGLogLevel
OFF → const TGLogLevel

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int

Available on TGLogLevel, provided by the TGLogLevelExtension extension

Gets value of the TGLogLevel
no setter

Methods

fromString(String value) → TGLogLevel

Available on TGLogLevel, provided by the TGLogLevelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TGLogLevel>
A constant List of the values in this enum, in order of their declaration.