TGFileUtil class

TGFramework's File related implementation

Constructors

TGFileUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

readFile(String path) → Future<String>
Reads file as String
readJsonFileAsList(String jsonFile) → Future<List>
Read JSon file as List
readJsonFileAsMap(String jsonFile) → Future<Map<String, dynamic>>
Read JSon file as Map
readJsonFileAsMapFromUrl(String jsonFileUrl) → Future<Map<String, dynamic>>
Read file as String from provided path and return as Map
readYamlFile(String yamlFile, {String? group, String? subGroup}) → Future<Map<String, dynamic>>
Read JSon file as Map specifically for provided group and subgroup